==> react-day-picker-0.5.0.tgz: package/src/DayPicker.js <==
import React from 'react';
import moment from 'moment';
import { weeks } from './utils';

const DayPicker = React.createClass({

  propTypes: {

    enableOutsideDays: React.PropTypes.bool,
    
    initialMonth: React.PropTypes.object, // default is current month
    modifiers: React.PropTypes.object,

    onDayClick: React.PropTypes.func,
    onDayTouchTap: React.PropTypes.func, // requires react-tap-event-plugin 
    onDayMouseEnter: React.PropTypes.func, 
    onDayMouseLeave: React.PropTypes.func, 

    onNextMonthClick: React.PropTypes.func, 
    onPrevMonthClick: React.PropTypes.func
  
  },

  getDefaultProps() {
    return { initialMonth: moment(), enableOutsideDays: false };
  },

  componentWillReceiveProps(nextProps) {
    if (!this.state.monthDidChange)
      this.setState({ month: nextProps.initialMonth });
  },
  
  getInitialState() {
    return {
      month: this.props.initialMonth.clone(),
      monthDidChange: false
    };
  },

  handleDayTouchTap(day, modifiers, e) {
    this.props.onDayTouchTap && this.props.onDayTouchTap(day, modifiers, e);
  },

  handleDayClick(day, modifiers, e) {
    this.props.onDayClick && this.props.onDayClick(day, modifiers, e);
  },

  handleDayMouseEnter(day, modifiers, e) {
    this.props.onDayMouseEnter && this.props.onDayMouseEnter(day, modifiers, e);
  },

  handleDayMouseLeave(day, modifiers, e) {
    this.props.onDayMouseLeave && this.props.onDayMouseLeave(day, modifiers, e);
  },

  handleNextMonthClick(e) {
    const { month } = this.state;
    const nextMonth = month.clone().add(1, 'month');
    this.setState({ month: nextMonth, monthDidChange: true }, () => {
      this.props.onNextMonthClick 
      && this.props.onNextMonthClick(this.state.month);
    });
  },

  handlePrevMonthClick(e) {
    const { month } = this.state;
    const prevMonth = month.clone().subtract(1, 'month');
    this.setState({ month: prevMonth, monthDidChange: true }, () => {
      this.props.onPrevMonthClick 
      && this.props.onPrevMonthClick(this.state.month);
    });
  },

  getModifiersForDay(day) {
    const { modifiers } = this.props;
    var dayModifiers = [];
    if (modifiers)
      for (let modifier in modifiers) {
        let func = modifiers[modifier];
        if (func(day)) dayModifiers.push(modifier);
      }
    return dayModifiers;
  },

  render() {
    const { month } = this.state;
    return (
      <table className="daypicker">
        <caption className="daypicker__caption">
          { this.renderNavButton('left') }
          { month.format('MMMM YYYY') }
          { this.renderNavButton('right') }
        </caption>
        <thead>
          { this.renderWeekHeader() }
        </thead>
        <tbody>
          { this.renderWeeks() }
        </tbody>
      </table>
    );
  },

  renderNavButton(position) {
    const className = `daypicker__nav daypicker__nav--${position}`;
    const handler = position === 'left' 
      ?  this.handlePrevMonthClick 
      :  this.handleNextMonthClick;

    return <span ref={"btn-"+position} className={className} 
      style={{float: position}} onClick={handler} />;
  },

  renderWeeks() {
    return weeks(this.state.month).map((week, i) => {
      return (
        <tr key={i} className="daypicker__week">
          { this.renderDays(week) }
        </tr>
      );
    });
  },

  renderWeekHeader() {
    var header = [];
    for (let i = 0; i < 7; i++) {
      header.push(
        <th key={i} className="daypicker__weekday">
          { moment().weekday(i).format('dd') }
        </th>
      )
    }
    return header;
  },

  renderDays(week) {
    const firstDay = week[0];
    const lastDay = week[week.length-1];
   
    var days = week.map(day => this.renderDay(day));

    // days belonging to the previous month
    for (let i = 0; i < firstDay.weekday(); i++) {
      var prevDay = firstDay.clone().subtract(i+1, 'day');
      days.unshift(this.renderDay(prevDay, true));
    }

    // days belonging to the next month
    for (let j = lastDay.weekday() + 1, count = 1; j < 7; j++, count++) {
      var nextDay = lastDay.clone().add(count, 'day');
      days.push(this.renderDay(nextDay, true));
    }

    return days;
  },

  renderDay(day, outside) {
    const key = `${day.dayOfYear()}`;
    var className = 'daypicker__day';
    if (outside) className += ' daypicker__day--outside';

    if (outside && !this.props.enableOutsideDays) {
      return <td className={className} ref={key} key={key} />;
    }
    else {
      const modifiers = this.getModifiersForDay(day);
      className += modifiers.map((mod) => { 
        return ' daypicker__day--' + mod 
      }).join('');
      return (
        <td ref={key} key={key} 
          className={className} 
          onMouseEnter={this.handleDayMouseEnter.bind(this, day, modifiers)}
          onMouseLeave={this.handleDayMouseLeave.bind(this, day, modifiers)}
          onTouchTap={this.handleDayTouchTap.bind(this, day, modifiers)}
          onClick={this.handleDayClick.bind(this, day, modifiers)}>
          { day.format('D') }
        </td>
      );
    }
  }

});

export default DayPicker;

==> react-day-picker-0.6.0.tgz: package/src/DayPicker.js <==
import React from 'react';
import moment from 'moment';
import { weeks } from './utils';

const DayPicker = React.createClass({

  propTypes: {

    enableOutsideDays: React.PropTypes.bool,
    
    initialMonth: React.PropTypes.object, // default is current month
    modifiers: React.PropTypes.object,

    onDayClick: React.PropTypes.func,
    onDayTouchTap: React.PropTypes.func, // requires react-tap-event-plugin 
    onDayMouseEnter: React.PropTypes.func, 
    onDayMouseLeave: React.PropTypes.func, 

    onNextMonthClick: React.PropTypes.func, 
    onPrevMonthClick: React.PropTypes.func
  
  },

  getDefaultProps() {
    return { initialMonth: moment(), enableOutsideDays: false };
  },

  getInitialState() {
    return { month: this.props.initialMonth.clone() };
  },

  handleDayTouchTap(day, modifiers, e) {
    this.props.onDayTouchTap && this.props.onDayTouchTap(day, modifiers, e);
  },

  handleDayClick(day, modifiers, e) {
    this.props.onDayClick && this.props.onDayClick(day, modifiers, e);
  },

  handleDayMouseEnter(day, modifiers, e) {
    this.props.onDayMouseEnter && this.props.onDayMouseEnter(day, modifiers, e);
  },

  handleDayMouseLeave(day, modifiers, e) {
    this.props.onDayMouseLeave && this.props.onDayMouseLeave(day, modifiers, e);
  },

  handleNextMonthClick(e) {
    const { month } = this.state;
    const nextMonth = month.clone().add(1, 'month');
    this.setState({ month: nextMonth }, () => {
      this.props.onNextMonthClick 
      && this.props.onNextMonthClick(this.state.month);
    });
  },

  handlePrevMonthClick(e) {
    const { month } = this.state;
    const prevMonth = month.clone().subtract(1, 'month');
    this.setState({ month: prevMonth }, () => {
      this.props.onPrevMonthClick 
      && this.props.onPrevMonthClick(this.state.month);
    });
  },

  getModifiersForDay(day) {
    const { modifiers } = this.props;
    var dayModifiers = [];
    if (modifiers)
      for (let modifier in modifiers) {
        let func = modifiers[modifier];
        if (func(day)) dayModifiers.push(modifier);
      }
    return dayModifiers;
  },

  showMonth(month) {
    this.setState({month: month});
  },

  render() {
    const { month } = this.state;
    return (
      <table className="daypicker">
        <caption className="daypicker__caption">
          { this.renderNavButton('left') }
          { month.format('MMMM YYYY') }
          { this.renderNavButton('right') }
        </caption>
        <thead>
          { this.renderWeekHeader() }
        </thead>
        <tbody>
          { this.renderWeeks() }
        </tbody>
      </table>
    );
  },

  renderNavButton(position) {
    const className = `daypicker__nav daypicker__nav--${position}`;
    const handler = position === 'left' 
      ?  this.handlePrevMonthClick 
      :  this.handleNextMonthClick;

    return <span ref={"btn-"+position} className={className} 
      style={{float: position}} onClick={handler} />;
  },

  renderWeeks() {
    return weeks(this.state.month).map((week, i) => {
      return (
        <tr key={i} className="daypicker__week">
          { this.renderDays(week) }
        </tr>
      );
    });
  },

  renderWeekHeader() {
    var header = [];
    for (let i = 0; i < 7; i++) {
      header.push(
        <th key={i} className="daypicker__weekday">
          { moment().weekday(i).format('dd') }
        </th>
      )
    }
    return header;
  },

  renderDays(week) {
    const firstDay = week[0];
    const lastDay = week[week.length-1];
   
    var days = week.map(day => this.renderDay(day));

    // days belonging to the previous month
    for (let i = 0; i < firstDay.weekday(); i++) {
      var prevDay = firstDay.clone().subtract(i+1, 'day');
      days.unshift(this.renderDay(prevDay, true));
    }

    // days belonging to the next month
    for (let j = lastDay.weekday() + 1, count = 1; j < 7; j++, count++) {
      var nextDay = lastDay.clone().add(count, 'day');
      days.push(this.renderDay(nextDay, true));
    }

    return days;
  },

  renderDay(day, outside) {
    const key = `${day.dayOfYear()}`;
    var className = 'daypicker__day';
    if (outside) className += ' daypicker__day--outside';

    if (outside && !this.props.enableOutsideDays) {
      return <td className={className} ref={key} key={key} />;
    }
    else {
      const modifiers = this.getModifiersForDay(day);
      className += modifiers.map((mod) => { 
        return ' daypicker__day--' + mod 
      }).join('');
      return (
        <td ref={key} key={key} 
          className={className} 
          onMouseEnter={this.handleDayMouseEnter.bind(this, day, modifiers)}
          onMouseLeave={this.handleDayMouseLeave.bind(this, day, modifiers)}
          onTouchTap={this.handleDayTouchTap.bind(this, day, modifiers)}
          onClick={this.handleDayClick.bind(this, day, modifiers)}>
          { day.format('D') }
        </td>
      );
    }
  }

});

export default DayPicker;
